@@ -67,11 +67,11 @@ resolver = "2" # avoid dependency conflicts on some platforms
 edition = "2018"
 
 [dependencies]
-sixtyfps = "0.1.3"
+sixtyfps = "0.1.4"
 ...
 
 [build-dependencies]
-sixtyfps-build = "0.1.3"
+sixtyfps-build = "0.1.4"
 ```
 
 In the `build.rs` file:
@@ -172,7 +172,7 @@ The follow table summarizes the entire mapping:
 
 For user defined structures in the .60, an extra struct is generated.
 For example, if the `.60` contains
-```60
+```60,ignore
 export struct MyStruct := {
     foo: int,
     bar: string,
@@ -219,7 +219,7 @@ pub use sixtyfps_corelib::graphics::{
     Brush, Color, Image, LoadImageError, Rgb8Pixel, Rgba8Pixel, RgbaColor, SharedPixelBuffer,
 };
 pub use sixtyfps_corelib::model::{
-    Model, ModelHandle, ModelNotify, ModelPeer, StandardListViewItem, VecModel,
+    Model, ModelHandle, ModelNotify, ModelPeer, ModelTracker, StandardListViewItem, VecModel,
 };
 pub use sixtyfps_corelib::sharedvector::SharedVector;
 pub use sixtyfps_corelib::string::SharedString;
@@ -725,7 +725,7 @@ macro_rules! include_modules {
 /// Helper type that helps checking that the generated code is generated for the right version
 #[doc(hidden)]
 #[allow(non_camel_case_types)]
-pub struct VersionCheck_0_1_3;
+pub struct VersionCheck_0_1_4;
 
 #[cfg(doctest)]
 mod compile_fail_tests;
